@@ -10,7 +10,7 @@ from .vec3 import Vec3
 class Prims(enum.Enum):
     """Enum for the default primitives that can be loaded."""
 
-    BUDDAH = "buddah"
+    BUDDHA = "buddah"
     BUNNY = "bunny"
     CUBE = "cube"
     DODECAHEDRON = "dodecahedron"
@@ -21,6 +21,14 @@ class Prims(enum.Enum):
     TEAPOT = "teapot"
     TETRAHEDRON = "tetrahedron"
     TROLL = "troll"
+    SPHERE = "sphere"
+    TORUS = "torus"
+    LINE_GRID = "line_grid"
+    TRIANGLE_PLANE = "triangle_plane"
+    CONE = "cone"
+    CAPSULE = "capsule"
+    CYLINDER = "cylinder"
+    DISK = "disk"
 
 
 def _circle_table(n: int) -> np.ndarray:
@@ -597,6 +605,9 @@ class PrimData:
     def primitive(name: Union[str, enum]) -> np.ndarray:
         prim_folder = Path(__file__).parent / "PrimData"
         prims = np.load(prim_folder / "Primitives.npz")
+        if isinstance(name, PrimData):
+            name = name.value
+
         try:
             return prims[name]
         except KeyError:
